@@ -3,7 +3,6 @@ import logging
 import os
 import struct
 import weakref
-import _md5  # Python's build-in MD5 is about 2x faster than hashlib.md5 on short bytestrings
 from collections import OrderedDict, deque
 from typing import Optional
 
@@ -12,6 +11,12 @@ try:
 except ImportError:
     import pickle
 
+try:
+    # Python's build-in MD5 is about 2x faster than hashlib.md5 on short bytestrings
+    import _md5 as md5
+except ImportError:
+    import hashlib as md5
+
 l = logging.getLogger("claripy.ast")
 
 WORKER = bool(os.environ.get('WORKER', False))
@@ -267,7 +272,7 @@ class Base:
         # Why do we use md5 when it's broken? Because speed is more important
         # than cryptographic integrity here. Then again, look at all those
         # allocations we're doing here... fast python is painful.
-        hd = _md5.md5(to_hash).digest()
+        hd = md5.md5(to_hash).digest()
         return md5_unpacker.unpack(hd)[0] # 64 bits
 
     @staticmethod
